| Home | Libraries | People | FAQ | More

### Acknowledgements

This library would not have happened without:

- Christopher Kormanyos' C++ decimal number code.
- Paul Bristow for patiently testing, and commenting on the library.
- All the folks at GMP, MPFR and libtommath, for providing the "guts" that makes this library work.
- "The Art Of Computer Programming", Donald E. Knuth, Volume 2: Seminumerical Algorithms, Third Edition (Reading, Massachusetts: Addison-Wesley, 1997), xiv+762pp. ISBN 0-201-89684-2